﻿using System;
using System.Windows.Forms;
using org.mbed.RPC;
using System.Diagnostics;
using System.Threading;

namespace mbedRPC.Test
{
    public partial class mbedRCPTest : Form
    {
        DigitalOut led1;        // mbed DigitalOut RPC declaration -> LED1
        DigitalOut led2;        // mbed DigitalOut RPC declaration -> LED2
        DigitalOut led3;        // mbed DigitalOut RPC declaration -> LED3
        DigitalOut led4;        // mbed DigitalOut RPC declaration -> LED4
        PwmOut pwm;
        mbed mbed;              // the embed itself
        String comport;
        AnalogIn ad;
        Boolean task = false;
        public mbedRCPTest()
        {
            InitializeComponent();
        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            if (task) return;
            try
            {
                mbed.delete();
                Debug.Print("Complete");
            }
            catch (NullReferenceException ex)
            {
                Debug.Print("No Reference: " + ex.Message);
            }
            this.Close();
        }

        private void mbedRCPTest_Load(object sender, EventArgs e)
        {
            Debug.Print("mbed RPC Hello World");
        }

        private void flash()
        {
            int n = 2;
            try
            {
                for (int i = 0; i < n; i++)
                {
                    //Call the DigitalOut objects' methods 
                    led4.write(0);          // off
                    led1.write(1);          // on
                    led1.write(0);          // off
                    led2.write(1);          // on
                    led2.write(0);          // off
                    led3.write(1);          // on
                    led3.write(0);          // off
                    led4.write(1);          // on
                }
                led4.write(0);        // reset last state - all leds are off now
            }
            catch (NullReferenceException ex)
            {
                Debug.Print("No Reference: " + ex.Message);
            }
            task = false;
        }

        private void btnFlash_Click(object sender, EventArgs e)
        {
            if (task) return;
            else task = true;
            btnFlash.Text = "Is Flashing";
            btnExit.Enabled = false;
            btnFlash.Enabled = false;
            new Thread(new ThreadStart(flash)).Start();
            btnExit.Enabled = true;
            while (task) ;
            btnFlash.Enabled = true;
            btnFlash.Text = "Start Flash";
         }

        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            comport = comboBox1.Text;
            Debug.Print(comport);
           // mbed.delete();  // serial port
            mbed = new SerialRxTxRPC(comport, 115200);
            pwm = new PwmOut(mbed, mbed.p21);
            //Create new Digital Outputs on the mbed
            led1 = new DigitalOut(mbed, mbed.LED1);
            led2 = new DigitalOut(mbed, mbed.LED2);
            led3 = new DigitalOut(mbed, mbed.LED3);
            led4 = new DigitalOut(mbed, mbed.LED4);
            ad = new AnalogIn(mbed, mbed.p20);
        }

        private bool pwmOn = false;

        private void servomotor(object sender, EventArgs e)
        {
            if (task)
            {
                if(!pwmOn)  return;
            }
            else task = true;
            pwmOn = !pwmOn;
            Debug.Print("pwm "+pwmOn);
            
            if(pwmOn) new Thread(new ThreadStart(pwmServo)).Start();
        }
        private void pwmServo()
        {
            double start = 0.035f, end = 0.105f;
            double step = (end - start) / 5;
            try
            {
                while (pwmOn)
                {
                    for (double p = start; p < end; p += step)
                    {
                        pwm.write(p);
                        Thread.Sleep(100);
                    }
                    for (double p = end; p >= start; p -= step)
                    {
                        pwm.write(p);
                        Thread.Sleep(100);
                    }
                }
            }
            catch(Exception){
                Debug.Print("pwmServo panic!!");
            }
            task = false;
        }

        private void button2_Click(object sender, EventArgs e)
        {
            if (task) return;
            else task = true;
            //  this.button2.Visible = false;
          //new Thread( new ThreadStart(getTempetature)).Start();
           getTempetature();
           task = false;
        }

        private void getTempetature()
        {
 
            String deg;
            try
            {
            //    while (true)
                {
                    deg = (ad.read() * 3.3 * 100).ToString();
                    deg = deg.Substring(0, 4);
                    textBox1.Text = deg;
                    Thread.Sleep(1000);
                }
            }
            catch (Exception)
            {
                Debug.Print("ad error");
                Thread.Sleep(1000);
            }
        
        }         
 
    }
}

